@@ -97,6 +97,9 @@ class UsersRestServletV2(RestServlet):
         users = await self.store.get_users_paginate(
             start, limit, user_id, guests, deactivated
         )
+        for user in users:
+            expiration_ts = await self.store.get_expiration_ts_for_user(user["name"])
+            user["expiration_ts"] = expiration_ts
         ret = {"users": users}
         if len(users) >= limit:
             ret["next_token"] = str(start + len(users))
