@@ -32,17 +32,18 @@ class JitsiRestServlet(RestServlet):
     async def on_GET(self, request):
         requester = await self.auth.get_user_by_req(request)
 
-        jitsiUri = self.hs.config.jitsi_url
+        jitsiUrl = self.hs.config.jitsi_url
 
         return (
             200,
             {
-                "url": jitsiUri,
+                "url": jitsiUrl,
             },
         )
 
     def on_OPTIONS(self, request):
         return 200, {}
 
+
 def register_servlets(hs, http_server):
     JitsiRestServlet(hs).register(http_server)
